=======================
Will's Python Utilities
=======================


.. image:: https://img.shields.io/pypi/v/wkr.svg
        :target: https://pypi.python.org/pypi/wkr

.. image:: https://img.shields.io/travis/wroberts/wkr.py.svg
        :target: https://travis-ci.org/wroberts/wkr.py

.. image:: https://coveralls.io/repos/wroberts/wkr.py/badge.svg?branch=master
  :target: https://coveralls.io/r/wroberts/wkr.py?branch=master
     :alt: Test code coverage

.. image:: https://readthedocs.org/projects/wkr/badge/?version=latest
        :target: https://wkr.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/wroberts/wkr.py/shield.svg
     :target: https://pyup.io/repos/github/wroberts/wkr.py/
     :alt: Updates


Python utility library


* Free software: MIT license
* Documentation: https://wkr.readthedocs.io.


Features
--------

* TODO

Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
